@@ -1,4 +1,4 @@
-/*	$NetBSD: fd.c,v 1.161 2020/11/22 03:55:33 thorpej Exp $	*/
+/*	$NetBSD: fd.c,v 1.162 2021/04/24 23:36:49 thorpej Exp $	*/
 
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -101,7 +101,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: fd.c,v 1.161 2020/11/22 03:55:33 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fd.c,v 1.162 2021/04/24 23:36:49 thorpej Exp $");
 
 #include "opt_ddb.h"
 #include "opt_md.h"
@@ -688,7 +688,8 @@ fdcattach(struct fdc_softc *fdc, int pri)
 	for (fa.fa_drive = 0; fa.fa_drive < 4; fa.fa_drive++) {
 		fa.fa_deftype = NULL;		/* unknown */
 	fa.fa_deftype = &fd_types[0];		/* XXX */
-		if (config_found(fdc->sc_dev, (void *)&fa, fdprint) != NULL)
+		if (config_found(fdc->sc_dev, (void *)&fa, fdprint,
+				 CFARG_EOL) != NULL)
 			drive_attached = 1;
 	}
 
