@@ -212,14 +212,14 @@ ldc_rx_data(struct ldc_conn *lc, struct ldc_pkt *lp)
 	size_t len;
 
 	if (lp->stype != LDC_INFO) {
-		DPRINTF(("DATA/0x%02x\n", lp->stype));
+		printf("DATA/0x%02x\n", lp->stype);
 		ldc_reset(lc);
 		return;
 	}
 
 	if (lc->lc_state != LDC_SND_RTR &&
 	    lc->lc_state != LDC_SND_RDX) {
-		DPRINTF(("Spurious DATA/INFO: state %d\n", lc->lc_state));
+		printf("Spurious DATA/INFO: state %d\n", lc->lc_state);
 		ldc_reset(lc);
 		return;
 	}
@@ -231,7 +231,7 @@ ldc_rx_data(struct ldc_conn *lc, struct ldc_pkt *lp)
 	} else {
 		len = (lp->env & LDC_LEN_MASK);
 		if (lc->lc_len + len > sizeof(lc->lc_msg)) {
-			DPRINTF(("Buffer overrun\n"));
+			printf("Buffer overrun\n");
 			ldc_reset(lc);
 			return;
 		}
@@ -437,7 +437,6 @@ ldc_send_unreliable(struct ldc_conn *lc, void *msg, size_t len)
 	err = hv_ldc_tx_get_state(lc->lc_id, &tx_head, &tx_tail, &tx_state);
 	if (err != H_EOK || tx_state != LDC_CHANNEL_UP) {
 		mutex_exit(&lc->lc_txq->lq_mtx);
-		printf("%s: EIO\n", __func__);
 		return (EIO);
 	}
 
@@ -446,7 +445,6 @@ ldc_send_unreliable(struct ldc_conn *lc, void *msg, size_t len)
 	tx_avail %= lc->lc_txq->lq_nentries;
 	if (len > tx_avail * LDC_PKT_PAYLOAD) {
 		mutex_exit(&lc->lc_txq->lq_mtx);
-		printf("%s: EWOULDBLOCK\n", __func__);
 		return (EWOULDBLOCK);
 	}
 
@@ -469,7 +467,6 @@ ldc_send_unreliable(struct ldc_conn *lc, void *msg, size_t len)
 		if (err != H_EOK) {
 			printf("%s: hv_ldc_tx_set_qtail: %d\n", __func__, err);
 			mutex_exit(&lc->lc_txq->lq_mtx);
-			printf("%s: EIO\n", __func__);
 			return (EIO);
 		}
 		p += uimin(len, LDC_PKT_PAYLOAD);
