@@ -48,12 +48,19 @@
 #include <sparc64/dev/ldcvar.h>
 #include <sparc64/dev/viovar.h>
 
+#if 0
+#define VNET_DEBUG
+#endif
 #ifdef VNET_DEBUG
 #define DPRINTF(x)	printf x
 #else
 #define DPRINTF(x)
 #endif
-
+#if 0
+#define DPRINTF_TX(x)	printf x
+#else
+#define DPRINTF_TX(x)
+#endif
 #define VNET_TX_ENTRIES		32
 #define VNET_RX_ENTRIES		32
 
@@ -382,6 +389,10 @@ vnet_rx_intr(void *arg)
 	if (rx_state != lc->lc_rx_state) {
 		switch (rx_state) {
 		case LDC_CHANNEL_DOWN:
+#ifdef DEBUG
+			printf("vnet_rx_intr: ldc_channel_down\n");
+			Debugger();
+#endif		
 			lc->lc_tx_seqid = 0;
 			lc->lc_state = 0;
 			lc->lc_reset(lc);
@@ -419,6 +430,10 @@ vnet_rx_intr(void *arg)
 			break;
 		default:	
 			DPRINTF(("%s: unhandled rx_state %" PRIx64 "\n", __func__, rx_state));
+#ifdef DEBUG
+			printf("vnet_rx_intr: unhandled state\n");
+			Debugger();
+#endif		
 			break;
 		}
 		lc->lc_rx_state = rx_state;
@@ -444,8 +459,8 @@ vnet_rx_intr(void *arg)
 		break;
 
 	default:
-		DPRINTF(("%s: unhandled type %0x02/%0x02/%0x02\n",
-				 __func__, lp->type, lp->stype, lp->ctrl));
+		printf("%s: unhandled type %0x02/%0x02/%0x02\n",
+				 __func__, lp->type, lp->stype, lp->ctrl);
 		Debugger();
 		ldc_reset(lc);
 		break;
@@ -874,15 +889,23 @@ vnet_rx_vio_dring_data(struct vnet_softc *sc, struct vio_msg_tag *tag)
 			}
 
 			if (desc.hdr.dstate != VIO_DESC_READY)
+			{
+				//printf("desc not ready: %u\n", desc.hdr.dstate);
 				break;
+			}
 
 			if (desc.nbytes > (ETHER_MAX_LEN - ETHER_CRC_LEN)) {
 				if_statinc(ifp, if_ierrors);
+				printf("too big: %u\n", desc.nbytes);
 				goto skip;
 			}
 			
 			MGETHDR(m, M_DONTWAIT, MT_DATA);
 			if (m == NULL) {
+				printf("%s: MGETHDR failed\n", __func__);
+#ifdef DEBUG
+		Debugger();
+#endif		
 				DPRINTF(("%s: MGETHDR failed\n", __func__));
 				if_statinc(ifp, if_ierrors);
 				goto skip;
@@ -897,6 +920,10 @@ vnet_rx_vio_dring_data(struct vnet_softc *sc, struct vio_msg_tag *tag)
 			err = hv_ldc_copy(lc->lc_id, LDC_COPY_IN,
 			    desc.cookie[0].addr, pa, nbytes, &nbytes);
 			if (err != H_EOK) {
+#ifdef DEBUG
+					printf("err = %d\n", err);			
+		Debugger();
+#endif		
 				m_freem(m);
 				goto skip;
 			}
@@ -976,7 +1003,10 @@ vnet_rx_vio_dring_data(struct vnet_softc *sc, struct vio_msg_tag *tag)
 		break;
 
 	default:
-		DPRINTF(("DATA/0x%02x/DRING_DATA\n", tag->stype));
+		printf("DATA/0x%02x/DRING_DATA\n", tag->stype);
+#ifdef DEBUG
+		Debugger();
+#endif		
 		break;
 	}
 }
@@ -1133,6 +1163,7 @@ vnet_send_dring_data(struct vnet_softc *sc, uint32_t start_idx)
 void
 vnet_start(struct ifnet *ifp)
 {
+	DPRINTF_TX(("%s: entry\n", __func__));
 	struct vnet_softc *sc = ifp->if_softc;
 	struct ldc_conn *lc = &sc->sc_lc;
 	struct ldc_map *map = sc->sc_lm;
@@ -1144,21 +1175,21 @@ vnet_start(struct ifnet *ifp)
 	int err;
 	if (!(ifp->if_flags & IFF_RUNNING))
 	{
-		DPRINTF(("%s: not in RUNNING state\n", __func__));
+		DPRINTF_TX(("%s: not in RUNNING state\n", __func__));
 		return;
 	}
 	if (ifp->if_flags & IFF_OACTIVE)
 	{
-		DPRINTF(("%s: already active\n", __func__));
+		DPRINTF_TX(("%s: already active\n", __func__));
 		return;
 	}
 
 	if (IFQ_IS_EMPTY(&ifp->if_snd))
 	{
-		DPRINTF(("%s: queue is empty\n", __func__));
+		DPRINTF_TX(("%s: queue is empty\n", __func__));
 		return;
 	} else {
-		DPRINTF(("%s: queue size %d\n", __func__, ifp->if_snd.ifq_len));
+		DPRINTF_TX(("%s: queue size %d\n", __func__, ifp->if_snd.ifq_len));
 	}
 
 	/*
@@ -1168,7 +1199,7 @@ vnet_start(struct ifnet *ifp)
 	if (!ISSET(sc->sc_vio_state, VIO_RCV_RDX) ||
 	    !ISSET(sc->sc_vio_state, VIO_ACK_RDX))
 	{
-		DPRINTF(("%s: vio connection not established yet\n", __func__));
+		DPRINTF_TX(("%s: vio connection not established yet\n", __func__));
 		return;
 	}
 
@@ -1178,7 +1209,7 @@ vnet_start(struct ifnet *ifp)
 	 */
 	err = hv_ldc_tx_get_state(lc->lc_id, &tx_head, &tx_tail, &tx_state);
 	if (err != H_EOK) {
-		DPRINTF(("%s: no room in ldc transmit queue\n", __func__));
+		DPRINTF_TX(("%s: no room in ldc transmit queue\n", __func__));
 		return;
 	}
 	tx_tail += sizeof(struct ldc_pkt);
@@ -1186,13 +1217,13 @@ vnet_start(struct ifnet *ifp)
 	if (tx_tail == tx_head) {
 		ifp->if_flags |= IFF_OACTIVE;
 		{
-			DPRINTF(("%s: tail equals head\n", __func__));
+			DPRINTF_TX(("%s: tail equals head\n", __func__));
 			return;
 		}
 	}
 
 	if (sc->sc_xfer_mode == VIO_DESC_MODE) {
-		DPRINTF(("%s: vio_desc_mode\n", __func__));
+		DPRINTF_TX(("%s: vio_desc_mode\n", __func__));
 		vnet_start_desc(ifp);
 		return;
 	}
@@ -1202,24 +1233,26 @@ vnet_start(struct ifnet *ifp)
 		count = sc->sc_tx_prod - sc->sc_tx_cons;
 		if (count >= (sc->sc_vd->vd_nentries - 1) ||
 		    map->lm_count >= map->lm_nentries) {
-			DPRINTF(("%s: count issue\n", __func__));
+			DPRINTF_TX(("%s: count issue\n", __func__));
 			ifp->if_flags |= IFF_OACTIVE;
 			break;
 		}
 
 		buf = pool_get(&sc->sc_pool, PR_NOWAIT|PR_ZERO);
 		if (buf == NULL) {
-			DPRINTF(("%s: buff is NULL\n", __func__));
+			DPRINTF_TX(("%s: buff is NULL\n", __func__));
 			ifp->if_flags |= IFF_OACTIVE;
 			break;
 		}
 		IFQ_DEQUEUE(&ifp->if_snd, m);
 		if (m == NULL) {
+			DPRINTF_TX(("%s: m is NULL\n", __func__));
 			pool_put(&sc->sc_pool, buf);
 			break;
 		}
 
 		m_copydata(m, 0, m->m_pkthdr.len, buf + VNET_ETHER_ALIGN);
+	        DPRINTF_TX(("%s: copied %u bytes\n", __func__, m->m_pkthdr.len));
 		
 #if NBPFILTER > 0
 		/*
@@ -1228,9 +1261,9 @@ vnet_start(struct ifnet *ifp)
 		 */
 		if (ifp->if_bpf)
 		{
-			DPRINTF(("%s: before bpf\n", __func__));
+			DPRINTF_TX(("%s: before bpf\n", __func__));
 			bpf_mtap(ifp->if_bpf, m, BPF_DIRECTION_OUT);
-			DPRINTF(("%s: after bpf\n", __func__));
+			DPRINTF_TX(("%s: after bpf\n", __func__));
 		}
 #endif
 
@@ -1263,9 +1296,11 @@ vnet_start(struct ifnet *ifp)
 	membar_producer();
 
 	if (start != prod && sc->sc_peer_state != VIO_DP_ACTIVE) {
+	        DPRINTF_TX(("%s: about to send dring data\n", __func__));
 		vnet_send_dring_data(sc, start);
 		ifp->if_timer = 5;
 	}
+	DPRINTF_TX(("%s: exit\n", __func__));
 			
 }
 
