@@ -1,4 +1,4 @@
-/*	$NetBSD: autoconf.c,v 1.231 2021/05/12 23:22:33 thorpej Exp $ */
+/*	$NetBSD: autoconf.c,v 1.233 2021/07/03 19:39:07 palle Exp $ */
 
 /*
  * Copyright (c) 1996
@@ -48,7 +48,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.231 2021/05/12 23:22:33 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.233 2021/07/03 19:39:07 palle Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -156,9 +156,6 @@ int	mainbus_match(device_t, cfdata_t, void *);
 static	void mainbus_attach(device_t, device_t, void *);
 static  void get_ncpus(void);
 static	void get_bootpath_from_prom(void);
-#if 0
-static void bootstrap_sun4v(void);
-#endif
 
 /*
  * Kernel 4MB mappings.
@@ -184,6 +181,12 @@ struct intrmap intrmap[] = {
 	{ NULL,		0 }
 };
 
+#ifdef SUN4V
+#define __align32 __attribute__((__aligned__(32)))
+char sun4v_soft_state_booting[] __align32 = "NetBSD booting";
+char sun4v_soft_state_running[] __align32 = "NetBSD running";
+#endif
+
 int console_node, console_instance;
 struct genfb_colormap_callback gfb_cb;
 static void of_set_palette(void *, int, int, int, int);
@@ -342,12 +345,8 @@ die_old_boot_loader:
 	if (OF_getprop(findroot(), "compatible", buf, sizeof(buf)) > 0) {
 		if (strcmp(buf, "sun4us") == 0)
 			setcputyp(CPU_SUN4US);
-		else if (strcmp(buf, "sun4v") == 0) {
+		else if (strcmp(buf, "sun4v") == 0)
 			setcputyp(CPU_SUN4V);
-#if 0			
-			bootstrap_sun4v();
-#endif			
-		}
 	}
 
 	bi_howto = lookup_bootinfo(BTINFO_BOOTHOWTO);
@@ -365,51 +364,20 @@ die_old_boot_loader:
 
 	get_ncpus();
 	pmap_bootstrap(KERNBASE, bi_kend->addr);
-}
-#if 0
-/*
- * bootstrap_sun4v()
- * sun4v specific setup
- */
-void
-bootstrap_sun4v(void)
-{
 
-	/*	
-	 * Determine the sun4v hypervisor api version.
-	 * Currently the 'interrupt' group is the only one handled.
-	 * It has shown that hv_vintr_setstate() fails if the
-	 * incorrect api version is used.
-	 * Start with api major version 3, then try version 2 and
-	 * finally version 1.
-	 * 
-	 */
-		
-	int64_t rc;
-	uint64_t major;
-	uint64_t minor;
-	uint64_t actual;
-	major = 3;
-	minor = 0;
-	actual = 0;	
-	rc = hv_api_set_version(HV_API_GROUP_INTERRUPT, major, minor, &actual);
-	if (rc != H_EOK) {
-		major = 2;
-		minor = 0;
-		actual = 0;	
-		rc = hv_api_set_version(HV_API_GROUP_INTERRUPT, major, minor, &actual);
-		if (rc != H_EOK) {
-			major = 1;
-			minor = 0;
-			actual = 0;	
-			rc = hv_api_set_version(HV_API_GROUP_INTERRUPT, major, minor, &actual);
-			if (rc != H_EOK) {
-				panic("Cannot determine sun4v hypervisor api version");
-			}
-		}
+#ifdef SUN4V
+	if (CPU_ISSUN4V) {
+		sun4v_soft_state_init();
+		sun4v_set_soft_state(SIS_TRANSITION, sun4v_soft_state_booting);
+		sun4v_interrupt_init();
+#if 0
+XXX notyet		
+		sun4v_sdio_init();
+#endif 
 	}
-}
 #endif
+}
+
 /*
  * get_bootpath_from_prom()
  * fetch the OF settings to identify our boot device during autoconfiguration
@@ -436,7 +404,6 @@ get_bootpath_from_prom(void)
 			return;
 		strcpy(ofbootpath, sbuf);
 	}
-	printf("bootpath: %s\n", ofbootpath);
 	DPRINTF(ACDB_BOOTDEV, ("bootpath: %s\n", ofbootpath));
 	ofbootpackage = prom_finddevice(ofbootpath);
 
@@ -550,8 +517,14 @@ cpu_configure(void)
         setpstate(getpstate()|PSTATE_IE);
 
 	(void)spl0();
+
+#ifdef SUN4V
+	if (CPU_ISSUN4V)
+		sun4v_set_soft_state(SIS_NORMAL, sun4v_soft_state_running);
+#endif
 }
 
+
 void
 cpu_rootconf(void)
 {
@@ -1148,15 +1121,7 @@ device_register(device_t dev, void *aux)
 			dev_bi_unit_drive_match(dev, ofnode,
 			    periph->periph_target + off, 0, periph->periph_lun);
 		}
-#if 0
-	/* More sun4v special stuff - booting from a vdisk (qemu) */
-	if (device_is_a(dev, "vofdisk")) {
-	  booted_device = dev;
-	  DPRINTF(ACDB_BOOTDEV, ("booted_device: %s\n", 
-				 device_xname(dev)));
-	  return;
-	}
-#endif		
+
 		if (device_is_a(busdev, "scsibus")) {
 			/* see if we're in a known SCA drivebay */
 			add_drivebay_props(dev, ofnode, aux);
