@@ -287,6 +287,13 @@ syscall(struct trapframe64 *tf, register_t code, register_t pc)
 	vaddr_t opc, onpc;
 	int s64;
 
+#if 0
+#define __align32 __attribute__((__aligned__(32)))
+char sun4v_soft_state_syscall[32] __align32 = "";
+ snprintf(sun4v_soft_state_syscall, 32, "syscall() 0x%p %x", (void*)pc, (unsigned int)code);
+	sun4v_set_soft_state(SIS_NORMAL, sun4v_soft_state_syscall);
+#endif	
+	
 #if 0
 #ifdef DEBUG
 	printf("syscall() pc =%p\n", (void*)pc);
@@ -352,6 +359,12 @@ syscall(struct trapframe64 *tf, register_t code, register_t pc)
   }
 #endif
 	
+#if 1
+#define __align32 __attribute__((__aligned__(32)))
+char sun4v_soft_state_syscall[32] __align32 = "";
+ snprintf(sun4v_soft_state_syscall, 32, "syscall() 0x%p %x", (void*)pc, (unsigned int)code);
+	sun4v_set_soft_state(SIS_NORMAL, sun4v_soft_state_syscall);
+#endif	
 	error = sy_invoke(callp, l, args.r, rval, code);
 
 	switch (error) {
