@@ -949,6 +949,14 @@ trap(struct trapframe64 *tf, unsigned int type, vaddr_t pc, long tstate)
 	/* This steps the PC over the trap. */
 #define	ADVANCE (n = tf->tf_npc, tf->tf_pc = n, tf->tf_npc = n + 4)
 
+#if 0
+#define __align32 __attribute__((__aligned__(32)))
+char sun4v_soft_state_trap[32] __align32 = "";
+        snprintf(sun4v_soft_state_trap, 32, "trap() 0x%p", (void*)pc);
+		sun4v_set_soft_state(SIS_NORMAL, sun4v_soft_state_trap);
+#endif	
+
+	
 #ifdef DEBUG
 #if 0	
 	printf("trap: type 0x%x: pc=%lx &tf=%p\n",
